// Test program for the Vaunix LSW Driver Interface
//
#include <stdbool.h>    /* AK: Added include for 'bool' type */
#include <stdio.h>
#include <unistd.h>     /* AK: Added include for error-free getlogin(). */
#include <math.h>
#include <string.h>     /* HME Added during the 0.1->1.0 switch */
#include "lswdrvr.h"

#define FALSE 0
#define TRUE !FALSE

#define SET_CONFIG  0
#define SAVE_CONFIG  0

#define DEBUG_LEVEL 1

char* lswdevices[] = {"192.168.100.10"};

#define LSW_DEVICES  (sizeof(lswdevices)/sizeof(lswdevices[0]))

/* code begins here */
int main (int argc, char *argv[]) {
    bool realhardware;
    unsigned int index;
	int swindex;
    STATUS_REPORT_T status;
    LSWDEVICE_DATA_T  lswdevicedata[LSW_DEVICES]; // MAX DEVICES list

    if (DEBUG_LEVEL > 0) printf("Calling fnLSW_Init()\r\n");
    fnLSW_Init();
    /* If you have actual hardware attached, set this to TRUE. Setting to FALSE will run in test mode */
    realhardware = TRUE;
    fnLSW_SetTestMode(!realhardware);

    printf("LSW Devices Length:%ld\n",LSW_DEVICES);

    /* Open all the lsw devices Socket connection in the list */
    for (index=0; index <LSW_DEVICES; index++)
    {
        if(fnLSW_InitDevice(lswdevices[index]))
            printf("Device Socket Connection Error:%s\n",lswdevices[index]);
    }

    // Print all the get parameters status
    for (index=0; index <LSW_DEVICES; index++)
    {
        if(DEBUG_LEVEL > 0)
        {
            if(fnLSW_CheckDeviceReady(lswdevices[index])== STATUS_OK)
            {
                // Device IP
                 printf("Device IP:%s\n",lswdevices[index]);
                 printf("----------------------------------------------\n");

                // Device Name
                fnLSW_GetModelName(lswdevices[index], lswdevicedata[index].modelname);
                printf("Model Name:%s\n",lswdevicedata[index].modelname);

                // Serial#
                fnLSW_GetSerialNumber(lswdevices[index], &lswdevicedata[index].serialnumber);
                printf("Serial Number:%d\n",lswdevicedata[index].serialnumber);

                // Sw Version #
                fnLSW_GetSoftwareVersion(lswdevices[index], lswdevicedata[index].swversion);
                printf("SW Version:%s\n",lswdevicedata[index].swversion);

                // IP Mode
                fnLSW_GetIPMode(lswdevices[index], &lswdevicedata[index].ipmode);
                printf("IP Mode:%d\n",lswdevicedata[index].ipmode);

                // IP Address
                fnLSW_GetIPAddress(lswdevices[index], lswdevicedata[index].ipaddress);
                printf("IP Address:%s\n",lswdevicedata[index].ipaddress);

                // Netmask
                fnLSW_GetNetmask(lswdevices[index], lswdevicedata[index].netmask);
                printf("Subnet Mask:%s\n",lswdevicedata[index].netmask);

                // Gateway
                fnLSW_GetGateway(lswdevices[index], lswdevicedata[index].gateway);
                printf("Gateway:%s\n",lswdevicedata[index].gateway);

				// Get max switches
				fnLSW_GetMaxSwitchDevices(lswdevices[index],&lswdevicedata[index].maxswitchdevices);
				printf("Max Switch Devices:%d\n",lswdevicedata[index].maxswitchdevices);

				// Switch RF output SW1
				for(swindex=1; swindex <= lswdevicedata[index].maxswitchdevices; swindex++)
				{
					fnLSW_GetSwitchRFoutput(lswdevices[index], swindex, &lswdevicedata[index].rfswitchoutput[swindex-1]);
					printf("SW%d-RF Output:%d\n",swindex, lswdevicedata[index].rfswitchoutput[swindex-1]);
				}

            }
        }
    }   

    // Device 0 Set Command Test  -- Check Device 0 ready or not
    if(fnLSW_CheckDeviceReady(lswdevices[0])== STATUS_OK)
    {

#if SET_CONFIG
		// Set SW1 to PORT3
		fnLSW_SetSwitchRFoutput(lswdevices[0], 1, SW_PORT3); 

		// Switch RF output SW1
		swindex = 1; // For SW1
		fnLSW_GetSwitchRFoutput(lswdevices[0], swindex, &lswdevicedata[0].rfswitchoutput[swindex-1]);
		printf("SW%d-RF Output:%d\n",swindex, lswdevicedata[0].rfswitchoutput[swindex-1]);

#endif

    
#if SAVE_CONFIG  
    // Save Settings Configuration
    fnLSW_SaveSettings(lswdevices[0]);   // Save current configuration API

#endif
        
    }
    while(1);
}

